@@ -28,6 +28,7 @@ from pylons.i18n.translation import _get_translator
 
 pylonsapp = None
 
+
 class PylonsPlugin(nose.plugins.Plugin):
     """Nose plugin extension
 
@@ -73,7 +74,15 @@ class PylonsPlugin(nose.plugins.Plugin):
         self.app = pylonsapp = loadapp('config:' + self.config_file,
                                        relative_to=path)
 
+        # Setup the config and app_globals, only works if we can get
+        # to the config object
+        conf = getattr(pylonsapp, 'config')
+        if conf:
+            pylons.config._push_object(conf)
+
+            if 'pylons.app_globals' in conf:
+                pylons.app_globals._push_object(conf['pylons.app_globals'])
+
         # Initialize a translator for tests that utilize i18n
         translator = _get_translator(pylons.config.get('lang'))
         pylons.translator._push_object(translator)
-
