@@ -6,7 +6,8 @@ from webob.exc import status_map
 import pylons
 from pylons.controllers import WSGIController
 
-from __init__ import TestWSGIController, SetupCacheGlobal, ControllerWrap, TestMiddleware
+from pylons.testutil import SetupCacheGlobal, ControllerWrap
+from __init__ import TestWSGIController, TestMiddleware
 
 class BasicWSGIController(WSGIController):
     def __init__(self):
@@ -151,17 +152,19 @@ class TestBasicWSGI(TestWSGIController):
         assert resp.response.headers['Cache-Control'] == 'private'
 
     def test_unicode_action(self):
-        self.baseenviron['pylons.routes_dict']['action'] = u'ОбсуждениеКомпаний'
+        self.baseenviron['pylons.routes_dict']['action'] = u'ÐžÐ±ÑÑƒÐ¶Ð´ÐµÐ½Ð¸ÐµÐšÐ¾Ð¼Ð¿Ð°Ð½Ð¸Ð¹'
         resp = self.app.get('/', status=404)
 
     def test_params(self):
         self.baseenviron['pylons.routes_dict']['action'] = u'params'
         resp = self.app.get('/?foo=bar')
-        assert "[('foo', u'bar')]" in resp, str(resp)
+        assert "'foo', u'bar')]" in resp, str(resp)
         resp = self.app.post('/?foo=bar', params=dict(snafu='snafoo'))
-        assert "[('foo', u'bar'), ('snafu', u'snafoo')]" in resp, str(resp)
+        assert "'foo', u'bar')" in resp, str(resp)
+        assert "'snafu', u'snafoo')]" in resp, str(resp)
         resp = self.app.put('/?foo=bar', params=dict(snafu='snafoo'))
-        assert "[('foo', u'bar'), ('snafu', u'snafoo')]" in resp, str(resp)
+        assert "'foo', u'bar')" in resp, str(resp)
+        assert "'snafu', u'snafoo')]" in resp, str(resp)
 
     def test_list(self):
         self.baseenviron['pylons.routes_dict']['action'] = 'list'
